==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/medias/lang/medias_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/medias?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'Sem som',
	'aucun_document' => 'Nenhum documento',
	'aucun_file' => 'nenhum documento',
	'aucun_image' => 'Nenhuma imagem',
	'aucun_video' => 'Sem vídeo',
	'aucune_utilisation' => 'Este documento não é usado',
	'aucune_vignette' => 'Nenhuma miniatura',

	// B
	'bouton_ajouter_document' => 'Incluir ao documento',
	'bouton_ajouter_image' => 'Incluir uma imagem',
	'bouton_ajouter_image_document' => 'Incluir uma imagem ou um documento',
	'bouton_attacher_document' => 'Anexar',
	'bouton_copier_local' => 'Copiar no site',
	'bouton_download_depuis' => 'local :',
	'bouton_download_local' => 'meu computador',
	'bouton_download_par_ftp' => 'do servidor',
	'bouton_download_par_mediatheque' => 'biblioteca de mídia',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Desvincular',
	'bouton_enlever_supprimer_document' => 'Remover',
	'bouton_enlever_supprimer_document_confirmation' => 'Tem certeza de que deseja remover o documento?',
	'bouton_modifier_document' => 'Editar',
	'bouton_parcourir' => 'Procurar... ',
	'bouton_refresh_document' => 'Atualizar o documento',
	'bouton_remplacer_document' => 'Substituir este documento',
	'bouton_remplacer_image' => 'Substituir esta imagem',
	'bouton_remplacer_image_document' => 'Substituir por imagem ou documento',
	'bouton_supprimer' => 'Remover',
	'bouton_supprimer_tous_orphelins' => 'Remover todas as não usadas',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Deseja realmente remover os @nb@ documentos que não estão em uso?',
	'bouton_upload' => 'Download',

	// D
	'des_audios' => '@nb@ sons',
	'des_documents' => '@nb@ documentos',
	'des_files' => '@nb@ documentos',
	'des_images' => '@nb@ imagens',
	'des_utilisations' => '@nb@ utilizações',
	'des_videos' => '@nb@ vídeos',
	'descriptif' => 'Descrição',
	'document_attache_succes' => 'O documento foi adicionado com sucesso',
	'document_copie_locale_succes' => 'O arquivo foi copiado com sucesso para o site',
	'document_installe_succes' => 'O arquivo foi carregado com sucesso',
	'document_vu' => 'Inserido no texto',
	'documents' => 'Biblioteca de mídia',
	'documents_brises' => 'Danificados',
	'documents_distants' => 'Remotos',
	'documents_locaux' => 'Locais',
	'documents_non_publies' => 'Não publicados',
	'documents_orphelins' => 'Não usados',
	'documents_publies' => 'Publicados',
	'documents_tous' => 'Todos',
	'double_clic_inserer_doc' => 'Faça um clique duplo para inserir este atalho no texto',

	// E
	'entree_dimensions' => 'Dimensões:',
	'entree_titre_document' => 'Título do documento:',
	'entree_titre_image' => 'Título da imagem:',
	'erreur_aucun_document' => 'Este documento não existe na biblioteca de mídia',
	'erreur_aucun_fichier' => 'Nenhum documento encontrado',
	'erreur_chemin_distant' => 'O arquivo remoto @nom@ não foi encontrado',
	'erreur_chemin_ftp' => 'O arquivo indicado não foi encontrado no servidor',
	'erreur_copie_fichier' => 'Impossível copiar o arquivo @nom@',
	'erreur_dossier_tmp_manquant' => 'Falta um diretório temporário para fazer carregamento dos arquivos',
	'erreur_ecriture_fichier' => 'Erro ao gravar arquivo em disco',
	'erreur_format_fichier_image' => 'O formato de @nom@ não é adequado para uma imagem',
	'erreur_indiquez_un_fichier' => 'Indique um arquivo !',
	'erreur_insertion_document_base' => 'Impossível salvar o documento @fichier@ no banco de dados',
	'erreur_suppression_vignette' => 'Erro ao apagar a miniatura',
	'erreur_upload_type_interdit' => 'O carregamento dos arquivos do tipo @nom@ não é autorizado',
	'erreur_upload_vignette' => 'Erro no carregamento da miniatura @nom@',
	'erreurs' => '@nb@ erros',
	'erreurs_voir' => 'Visualizar os @nb@ erros',

	// F
	'fichier_distant' => 'Arquivo remoto',
	'fichier_manquant' => 'Arquivo faltante',
	'fichier_modifie' => 'O arquivo foi modificado. Clique em salvar.',
	'format_date_incorrect' => 'A data ou a hora estão incorretas',

	// I
	'icone_creer_document' => 'Adicionar ao documento',
	'id' => 'ID',
	'image_tourner_180' => 'Rodar 180°',
	'image_tourner_droite' => 'Rodar 90° à direita',
	'image_tourner_gauche' => 'Rodar 90° à esquerda',
	'info_doc_max_poids' => 'Os documentos devem obrigatoriamente ter menos de @maxi@ (este documento tem @actuel@).',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Este documento não está disponível',
	'info_documents' => 'Documentos',
	'info_gauche_numero_document' => 'Documento número',
	'info_hauteur' => 'Altura',
	'info_heure' => 'Tempo',
	'info_illustrations' => 'Ilustrações',
	'info_image_max_poids' => 'As imagens devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
	'info_inclusion_directe' => 'Inclusão direta:',
	'info_inclusion_vignette' => 'Inclusão do ícone:',
	'info_installer_tous_documents' => 'Instalar todos os documentos',
	'info_largeur' => 'Largura',
	'info_logo_max_taille' => 'Os ícones devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
	'info_mode' => 'Modo',
	'info_modifier_document' => 'Editar documento',
	'info_portfolio' => 'Portfólio',
	'info_referencer_doc_distant' => 'Referenciar um documento na internet:',
	'info_sans_vignette' => 'Sem miniatura',
	'info_statut_document' => 'Este documento é:',
	'info_taille' => 'Tamanho',
	'info_telecharger' => 'Transferir do seu computador:',
	'infos' => 'Exibir informações técnicas',
	'item_autoriser_selectionner_date_en_ligne' => 'Permite modificar a data de cada documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'A data dos documentos é a mesma da incorporação ao site',

	// L
	'label_activer_document_objets' => 'Permitir o carregamento de documentos para:',
	'label_apercu' => 'Pré-visualização',
	'label_caracteristiques' => 'Características',
	'label_credits' => 'Créditos',
	'label_fichier' => 'Arquivo',
	'label_fichier_vignette' => 'Miniatura',
	'label_paginer_par' => 'Paginar por:',
	'label_parents' => 'Este documento está relacionado a',
	'label_refdoc_joindre' => 'Número do documento',
	'lien_tout_enlever' => 'Remover todos',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Sons',
	'media_file' => 'Outro',
	'media_image' => 'Imagens',
	'media_video' => 'Sequências',
	'miniature_automatique_active' => 'SPIP criará automaticamente uma miniatura da imagem',

	// N
	'nb_documents_attache_succes' => '@nb@ documentos foram adicionados',
	'nb_documents_installe_succes' => '@nb@ arquivos carregados com sucesso',

	// O
	'objet_document' => 'Documento',
	'objet_documents' => 'Documentos',

	// P
	'par_date' => 'Data',
	'par_hauteur' => 'Altura',
	'par_id' => 'ID',
	'par_largeur' => 'Largura',
	'par_taille' => 'Peso',
	'par_titre' => 'Título',

	// T
	'texte_documents_joints' => 'Você pode autorizar a inclusão de documentos (arquivos, imagens,  multimídia etc.) às matérias e/ou às seções. Estes arquivos podem, em seguida, ser referenciados na matéria, ou exibidos separadamente.',
	'texte_documents_joints_2' => 'Essa escolha não impede a inserção de imagens diretamente nas matérias.',
	'titre_documents_joints' => 'Documentos anexados',
	'titre_page_documents_edit' => 'Modificar o documento: @titre@',
	'tous_les_medias' => 'Todas as mídias',
	'tout_dossier_upload' => 'Todo o diretório @upload@',
	'tout_voir' => 'Ver todos',

	// U
	'un_audio' => '1 som',
	'un_document' => '1 documento',
	'un_file' => '1 documento',
	'un_image' => '1 imagem',
	'un_video' => '1 vídeo',
	'une_utilisation' => '1 utilização',
	'upload_fichier_zip' => 'Arquivo ZIP',
	'upload_fichier_zip_texte' => 'O arquivo que você propôs instalar é um arquivo Zip.',
	'upload_fichier_zip_texte2' => 'Este arquivo pode ser:',
	'upload_info_mode_document' => 'Coloque no portfolio',
	'upload_info_mode_image' => 'Retirar do portfolio',
	'upload_limit' => 'Este arquivo é grande demais para o servidor; o tamanho máximo autorizado para <i>upload</i> é de @max@.',
	'upload_zip_conserver' => 'Manter o arquivo após extração',
	'upload_zip_decompacter' => 'expandido e cada elemento que ele contém gravados no site. Os arquivos que serão então gravados são:',
	'upload_zip_mode_document' => 'Colocar todas as imagens no portfólio',
	'upload_zip_telquel' => 'instalado; como arquivo compactado Zip;',
	'upload_zip_titrer' => 'Titular de acordo com o nome dos arquivos',

	// V
	'verifier_documents_brises' => 'Verifique se há arquivos ausentes',
	'verifier_documents_inutilises' => 'Verifique os links dos documentos',
	'vignette_supprimee' => 'A miniatura foi removida'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/medias/lang/medias_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/medias?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'Nemhum som',
	'aucun_document' => 'Nenhum documento',
	'aucun_file' => 'Nenhum documento',
	'aucun_image' => 'Nenhuma imagem',
	'aucun_video' => 'Nemhum vídeo',
	'aucune_utilisation' => 'Este documento não é usado',
	'aucune_vignette' => 'Nenhuma miniatura',

	// B
	'bouton_ajouter_document' => 'Incluir ao documento',
	'bouton_ajouter_image' => 'Incluir uma imagem',
	'bouton_ajouter_image_document' => 'Incluir uma imagem ou um documento',
	'bouton_attacher_document' => 'Anexar',
	'bouton_copier_local' => 'Copiar no site',
	'bouton_download_depuis' => 'local :',
	'bouton_download_local' => 'meu computador',
	'bouton_download_par_ftp' => 'do servidor',
	'bouton_download_par_mediatheque' => 'biblioteca de mídia',
	'bouton_download_sur_le_web' => 'internet',
	'bouton_enlever_document' => 'Desvincular',
	'bouton_enlever_supprimer_document' => 'Remover',
	'bouton_enlever_supprimer_document_confirmation' => 'Tem certeza de que deseja remover o documento?',
	'bouton_modifier_document' => 'Editar',
	'bouton_parcourir' => 'Procurar... ',
	'bouton_refresh_document' => 'Atualizar o documento',
	'bouton_remplacer_document' => 'Substituir este documento',
	'bouton_remplacer_image' => 'Substituir esta imagem',
	'bouton_remplacer_image_document' => 'Substituir por imagem ou documento',
	'bouton_supprimer' => 'Remover',
	'bouton_supprimer_tous_orphelins' => 'Remover todas as não usadas',
	'bouton_supprimer_tous_orphelins_confirmation' => 'Deseja realmente remover os @nb@ documentos que não estão em uso?',
	'bouton_upload' => 'Download',

	// D
	'des_audios' => '@nb@ sons',
	'des_documents' => '@nb@ documentos',
	'des_files' => '@nb@ documentos',
	'des_images' => '@nb@ imagens',
	'des_utilisations' => '@nb@ utilizações',
	'des_videos' => '@nb@ vídeos',
	'descriptif' => 'Descrição',
	'document_attache_succes' => 'O documento foi adicionado com sucesso',
	'document_copie_locale_succes' => 'O arquivo foi copiado com sucesso para o site',
	'document_installe_succes' => 'O arquivo foi carregado com sucesso',
	'document_vu' => 'Inserido no texto',
	'documents' => 'Biblioteca de mídia',
	'documents_brises' => 'Danificados',
	'documents_distants' => 'Remotos',
	'documents_locaux' => 'Locais',
	'documents_non_publies' => 'Não publicados',
	'documents_orphelins' => 'Não usados',
	'documents_publies' => 'Publicados',
	'documents_tous' => 'Todos',
	'double_clic_inserer_doc' => 'Faça um clique duplo para inserir este atalho no texto',

	// E
	'entree_dimensions' => 'Dimensões:',
	'entree_titre_document' => 'Título do documento:',
	'entree_titre_image' => 'Título da imagem:',
	'erreur_aucun_document' => 'Este documento não existe na biblioteca de mídia',
	'erreur_aucun_fichier' => 'Nenhum documento encontrado',
	'erreur_chemin_distant' => 'O arquivo remoto @nom@ não foi encontrado',
	'erreur_chemin_ftp' => 'O arquivo indicado não foi encontrado no servidor',
	'erreur_copie_fichier' => 'Impossível copiar o arquivo @nom@',
	'erreur_dossier_tmp_manquant' => 'Falta um diretório temporário para fazer carregamento dos arquivos',
	'erreur_ecriture_fichier' => 'Erro ao gravar arquivo em disco',
	'erreur_format_fichier_image' => 'O formato de @nom@ não é adequado para uma imagem',
	'erreur_indiquez_un_fichier' => 'Indique um arquivo !',
	'erreur_insertion_document_base' => 'Impossível salvar o documento @fichier@ no banco de dados',
	'erreur_suppression_vignette' => 'Erro ao apagar a miniatura',
	'erreur_upload_type_interdit' => 'O carregamento dos arquivos do tipo @nom@ não é autorizado',
	'erreur_upload_vignette' => 'Erro no carregamento da miniatura @nom@',
	'erreurs' => '@nb@ erros',
	'erreurs_voir' => 'Visualizar os @nb@ erros',

	// F
	'fichier_distant' => 'Arquivo remoto',
	'fichier_manquant' => 'Arquivo faltante',
	'fichier_modifie' => 'O arquivo foi modificado. Clique em salvar.',
	'format_date_incorrect' => 'A data ou a hora estão incorretas',

	// I
	'icone_creer_document' => 'Adicionar ao documento',
	'id' => 'ID',
	'image_tourner_180' => 'Rodar 180°',
	'image_tourner_droite' => 'Rodar 90° à direita',
	'image_tourner_gauche' => 'Rodar 90° à esquerda',
	'info_doc_max_poids' => 'Os documentos devem obrigatoriamente ter menos de @maxi@ (este documento tem @actuel@).',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Este documento não está disponível',
	'info_documents' => 'Documentos',
	'info_gauche_numero_document' => 'Documento número',
	'info_hauteur' => 'Altura',
	'info_heure' => 'Tempo',
	'info_illustrations' => 'Ilustrações',
	'info_image_max_poids' => 'As imagens devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
	'info_image_max_taille' => 'As imagens devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
	'info_inclusion_directe' => 'Inclusão direta:',
	'info_inclusion_vignette' => 'Inclusão da miniatura:',
	'info_installer_tous_documents' => 'Instalar todos os documentos',
	'info_largeur' => 'Largura',
	'info_logo_max_taille' => 'Os ícones devem obrigatoriamente ter menos de @maxi@ (este arquivo tem @actuel@).',
	'info_mode' => 'Modo',
	'info_modifier_document' => 'Editar documento',
	'info_portfolio' => 'Portfólio',
	'info_referencer_doc_distant' => 'Referenciar um documento na internet:',
	'info_sans_vignette' => 'Sem miniatura',
	'info_statut_document' => 'Este documento é:',
	'info_taille' => 'Tamanho',
	'info_telecharger' => 'Transferir do seu computador:',
	'infos' => 'Exibir informações técnicas',
	'item_autoriser_selectionner_date_en_ligne' => 'Permite modificar a data de cada documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'A data dos documentos é a mesma da incorporação ao site',

	// L
	'label_activer_document_objets' => 'Permitir o carregamento de documentos para:',
	'label_apercu' => 'Pré-visualização',
	'label_caracteristiques' => 'Características',
	'label_credits' => 'Créditos',
	'label_fichier' => 'Arquivo',
	'label_fichier_vignette' => 'Miniatura',
	'label_paginer_par' => 'Paginar por:',
	'label_parents' => 'Este documento está relacionado a',
	'label_refdoc_joindre' => 'Número do documento',
	'lien_tout_enlever' => 'Remover todos',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Sons',
	'media_file' => 'Outros',
	'media_image' => 'Imagens',
	'media_video' => 'Sequências',
	'miniature_automatique_active' => 'SPIP criará automaticamente uma miniatura da imagem',

	// N
	'nb_documents_attache_succes' => '@nb@ documentos foram adicionados',
	'nb_documents_installe_succes' => '@nb@ arquivos carregados com sucesso',

	// O
	'objet_document' => 'Documento',
	'objet_documents' => 'Documentos',

	// P
	'par_date' => 'Data',
	'par_hauteur' => 'Altura',
	'par_id' => 'ID',
	'par_largeur' => 'Largura',
	'par_taille' => 'Peso',
	'par_titre' => 'Título',

	// T
	'texte_documents_joints' => 'Você pode autorizar a inclusão de documentos (arquivos, imagens,  multimídia etc.) às matérias e/ou às seções. Estes arquivos podem, em seguida, ser referenciados na matéria, ou exibidos separadamente.',
	'texte_documents_joints_2' => 'Essa escolha não impede a inserção de imagens diretamente nas matérias.',
	'titre_documents_joints' => 'Documentos anexados',
	'titre_page_documents_edit' => 'Modificar o documento: @titre@',
	'tous_les_medias' => 'Todas as mídias',
	'tout_dossier_upload' => 'Todo o diretório @upload@',
	'tout_voir' => 'Ver todos',

	// U
	'un_audio' => '1 som',
	'un_document' => '1 documento',
	'un_file' => '1 documento',
	'un_image' => '1 imagem',
	'un_video' => '1 vídeo',
	'une_utilisation' => '1 utilização',
	'upload_fichier_zip' => 'Arquivo ZIP',
	'upload_fichier_zip_texte' => 'O arquivo que você propôs instalar é um arquivo Zip.',
	'upload_fichier_zip_texte2' => 'Este arquivo pode ser:',
	'upload_info_mode_document' => 'Coloque no portfolio',
	'upload_info_mode_image' => 'Retirar do portfolio',
	'upload_limit' => 'Este arquivo é grande demais para o servidor; o tamanho máximo autorizado para <i>upload</i> é de @max@.',
	'upload_zip_conserver' => 'Manter o arquivo após extração',
	'upload_zip_decompacter' => 'expandido e cada elemento que ele contém gravados no site. Os arquivos que serão então gravados são:',
	'upload_zip_mode_document' => 'Colocar todas as imagens no portfólio',
	'upload_zip_telquel' => 'instalado; como arquivo compactado Zip;',
	'upload_zip_titrer' => 'Titular de acordo com o nome dos arquivos',

	// V
	'verifier_documents_brises' => 'Verifique se há arquivos ausentes',
	'verifier_documents_inutilises' => 'Verifique os links dos documentos',
	'vignette_supprimee' => 'A miniatura foi removida'
);

?>
